@@ -5,7 +5,8 @@ from pprint import pprint
 from dotenv import load_dotenv
 from ghapi.all import GhApi
 from ghsearcher.helpers import RateLimiter
-from ghsearcher.helpers import paginator
+from ghsearcher.helpers import paginator, output_json_file
+from fastcore.xtras import obj2dict
 
 
 load_dotenv()
@@ -46,10 +47,10 @@ def search(query: str, endpoint:str = DEFAULT_ENDPOINT, client: GhApi = None) ->
   search_config = {
     'users': client.search.users,
     'code': client.search.code,
-    #'issues': client.search.issues,
+    'issues': client.search.issues_and_pull_requests,
     'commits': client.search.commits,
     'labels': client.search.labels,
-    #'repositories': client.search.repositories,
+    'repos': client.search.repos,
     'topics': client.search.topics
   }
 
@@ -63,22 +64,6 @@ def search(query: str, endpoint:str = DEFAULT_ENDPOINT, client: GhApi = None) ->
     yield results.get('items', [])
 
 
-def query_builder(query=None, scope=None, target=None):
-  full_query = [
-    query,
-    reduce_scope(scope, target)
-  ]
-
-  return " ".join(full_query)
-
-
-def reduce_scope(scope, target) -> str:
-  if scope != None and target != None:
-    return f"{scope}: {target}"
-
-  return ""
-
-
 def cli_entry():
   """Parse arguments and kickoff the process"""
   parser = argparse.ArgumentParser(
@@ -88,7 +73,7 @@ def cli_entry():
     '-v',
     '--version',
     action='version',
-    version='%(prog)s 0.0.2')
+    version='%(prog)s 0.0.3')
 
   parser.add_argument(
     '--debug',
@@ -101,15 +86,21 @@ def cli_entry():
     choices=[
       'users',
       'code',
-      #'issues',
+      'issues',
       'commits',
       'labels',
-      #'repositories',
+      'repos',
       'topics'
     ],
     default=DEFAULT_ENDPOINT,
     help='Endpoint you would like to search')
 
+  parser.add_argument(
+    '-o',
+    '--output-file',
+    help='File name for where you want the JSON output to go. eg: output/test \n' +
+          'will output a file in the output dir with the file name test-2022-01-01.json')
+
   parser.add_argument(
     '-q',
     '--query',
@@ -125,10 +116,17 @@ def cli_entry():
   client = get_client()
 
   results = []
-  for query in args.querys:
-    tmp = search(query, args.endpoint, client)
-    pprint(tmp)
-    results.extend(tmp)
+  for query in args.query:
+    search_gen = search(query, args.endpoint, client)
+    # Broken Functionality - Need to iterate over generator
+    for result_page in search_gen:
+      tmp_result = [ obj2dict(result) for result in result_page.items]
+      results.extend(tmp_result)
+
+  if args.output_file != None:
+    output_json_file(args.output_file, results)
+  else:
+    pprint(results)
 
 
 if __name__=='__main__':
